@@ -1,7 +1,8 @@
-__version__ = '0.6.0'
+__version__ = '0.6.2'
 
 from yarl import URL
 from distutils.version import StrictVersion
+from typing import Union
 
 import asyncio
 import aiohttp
@@ -39,6 +40,7 @@ class AsyncIPFS(object):
         (this is the preferred method of specifying the node's address)
     :param str host: Hostname/IP of the IPFS daemon to connect to
     :param int port: The API port of the IPFS deamon
+    :param str scheme: RPC API protocol: 'http' (default) or 'https'
     :param int conns_max: Maximum HTTP connections for this client
         (default: 0)
     :param int conns_max_per_host: Maximum per-host HTTP connections
@@ -52,7 +54,8 @@ class AsyncIPFS(object):
     def __init__(self,
                  host: str = 'localhost',
                  port: int = RPC_API_DEFAULT_PORT,
-                 maddr=None,
+                 scheme: str = 'http',
+                 maddr: Union[Multiaddr, str] = None,
                  loop=None,
                  conns_max: int = 0,
                  conns_max_per_host: int = 0,
@@ -64,11 +67,12 @@ class AsyncIPFS(object):
         self._conns_max_per_host = conns_max_per_host
         self._read_timeout = read_timeout
         self._debug = debug
-        self._host, self._port = None, None
+        self._host, self._port, self._scheme = None, None, None
         self.loop = loop if loop else asyncio.get_event_loop()
 
         self._api_url = self.__compute_base_api_url(host=host,
                                                     port=port,
+                                                    scheme=scheme,
                                                     maddr=maddr,
                                                     api_version=api_version)
 
@@ -123,15 +127,19 @@ class AsyncIPFS(object):
     @property
     def host_local(self):
         try:
-            addr = ipaddress.ip_address(self._host)
+            addr = ipaddress.ip_address(self.host)
             return addr.is_loopback
         except Exception:
-            return self._host in ['localhost', socket.gethostname()]
+            return self.host in ['localhost', socket.gethostname()]
 
     @property
     def port(self):
         return self._port
 
+    @property
+    def scheme(self):
+        return self._scheme
+
     @property
     def add(self):
         return self.core.add
@@ -188,7 +196,7 @@ class AsyncIPFS(object):
     def commands(self):
         return self.core.commands
 
-    def __compute_base_api_url(self, host=None, port=None,
+    def __compute_base_api_url(self, host=None, port=None, scheme='http',
                                maddr=None, api_version='v0'):
         """
         Compute and return the base kubo API url from the settings
@@ -214,6 +222,9 @@ class AsyncIPFS(object):
                         self._port = int(
                             node_maddr.value_for_protocol(proto.name)
                         )
+                    elif proto.name == 'https':
+                        scheme = 'https'
+                        self._scheme = scheme
 
                 assert isinstance(self._host, str)
                 assert isinstance(self._port, int)
@@ -226,13 +237,14 @@ class AsyncIPFS(object):
         elif isinstance(host, str) and isinstance(port, int):
             self._host = host
             self._port = port
+            self._scheme = scheme
         else:
             raise InvalidNodeAddressError()
 
         return URL.build(
-            host=self._host,
-            port=self._port,
-            scheme='http',
+            host=self.host,
+            port=self.port,
+            scheme=scheme,
             path=f'/api/{api_version}/'
         )
 
