@@ -15,150 +15,6 @@ from . import multi
 from .helpers import *  # noqa
 
 
-class P2PAPI(SubAPI):
-    """
-    P2P API.
-
-    Note: go-ipfs v0.4.18 introduced some changes in the P2P subsystem
-    and some endpoints were renamed. Agent version detection is done
-    in the affected API calls to maintain compatibility.
-    """
-    async def listener_open(self, protocol, address,
-                            allow_custom_protocol=False,
-                            report_peerid=False):
-        """
-        Open a P2P listener
-
-        :param str protocol: protocol name associated with the listener
-        :param str address: address for the listener, in multiaddr format
-        """
-
-        api_post0418 = await self.driver.agent_version_post0418()
-
-        if api_post0418 is True:
-            url = self.url('p2p/listen')
-            params = quote_dict({
-                ARG_PARAM: [protocol, address],
-                'allow-custom-protocol': boolarg(allow_custom_protocol),
-                'report-peer-id': boolarg(report_peerid)
-            })
-        else:
-            url = self.url('p2p/listener/open')
-            params = quote_args(protocol, address)
-
-        return await self.fetch_json(url, params=params)
-
-    async def listener_close(self, protocol, listen_address=None,
-                             target_address=None, all=False):
-        """
-        Close a previously opened P2P listener
-
-        :param str protocol: protocol name associated with the listener
-        :param bool all: if True, closes all listeners on the node
-        """
-
-        api_post0418 = await self.driver.agent_version_post0418()
-
-        if api_post0418 is True:
-            url = self.url('p2p/close')
-            params = {
-                'protocol': protocol,
-                'all': boolarg(all)
-            }
-
-            if listen_address:
-                params['listen-address'] = listen_address
-            if target_address:
-                params['target-address'] = target_address
-        else:
-            url = self.url('p2p/listener/close')
-            params = {
-                ARG_PARAM: protocol,
-                'all': boolarg(all)
-            }
-
-        return await self.fetch_json(url, params=params)
-
-    async def listener_ls(self, headers=False):
-        """
-        List P2P listeners
-
-        :param bool headers: print all headers (HandlerID, Protocol, ...)
-        """
-
-        api_post0418 = await self.driver.agent_version_post0418()
-
-        if api_post0418 is True:
-            url = self.url('p2p/ls')
-        else:
-            url = self.url('p2p/listener/ls')
-
-        return await self.fetch_json(url,
-                                     params={'headers': boolarg(headers)})
-
-    async def stream_dial(self, protocol, laddress, target,
-                          allow_custom_protocol=False):
-        """
-        Dial to a P2P listener.
-
-        :param str peer: Remote Peer ID
-        :param str protocol: protocol identifier
-        :param str address: multiaddr to listen for connection/s
-            (default: /ip4/127.0.0.1/tcp/0)
-        """
-
-        api_post0418 = await self.driver.agent_version_post0418()
-
-        if api_post0418 is True:
-            url = self.url('p2p/forward')
-            params = quote_dict({
-                ARG_PARAM: [protocol, laddress, target],
-                'allow-custom-protocol': boolarg(allow_custom_protocol)
-            })
-        else:
-            url = self.url('p2p/stream/dial')
-            args = [
-                target,
-                protocol,
-                laddress] if laddress else [
-                target,
-                protocol]
-            params = quote_args(*args)
-
-        return await self.fetch_json(url, params=params)
-
-    async def stream_close(self, stream_id=None, all=False):
-        """
-        Close active P2P stream.
-        """
-
-        if stream_id and all is False:
-            params = {
-                ARG_PARAM: stream_id,
-            }
-        elif all is True:
-            params = {
-                'all': boolarg(all)
-            }
-        else:
-            raise ValueError('Invalid stream parameters')
-
-        return await self.fetch_text(self.url('p2p/stream/close'),
-                                     params=params)
-
-    async def stream_ls(self, headers=False):
-        """
-        List active P2P streams.
-        """
-        return await self.fetch_json(self.url('p2p/stream/ls'),
-                                     params={'headers': boolarg(headers)})
-
-    listen = listener_open
-    dial = stream_dial
-    forward = stream_dial
-    ls = listener_ls
-
-
 class BitswapAPI(SubAPI):
     async def ledger(self, peer):
         """
